==> haskell-tasty-golden-2.3.4-110-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-golden
version:              2.3.4
visibility:           public
id:                   tasty-golden-2.3.4-4N3bJWgZ9VnJxZ6wzDleey
key:                  tasty-golden-2.3.4-4N3bJWgZ9VnJxZ6wzDleey
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka
homepage:             https://github.com/feuerbach/tasty-golden
synopsis:             Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.

category:             Testing
abi:                  3b485b7521461fcf2c8c6f0be92d42a7
exposed:              True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage

hidden-modules:       Test.Tasty.Golden.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/tasty-golden-2.3.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/tasty-golden-2.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/tasty-golden-2.3.4
hs-libraries:         HStasty-golden-2.3.4-4N3bJWgZ9VnJxZ6wzDleey
depends:
    async-2.2.3-JMLEcS5xCFd7RA7gdjgDSR base-4.15.0.0
    bytestring-0.10.12.1 containers-0.6.4.1 deepseq-1.4.5.0
    directory-1.3.6.1 filepath-1.4.2.1 mtl-2.2.2
    optparse-applicative-0.16.1.0-2Lys88r8Sg3GstjsK1qq7I
    process-1.6.11.0 tagged-0.8.6.1-FL843C40q4d1DeuwYADr25
    tasty-1.4.2-DOA9A3tFSRhHnd91ITmTdP
    temporary-1.3-AVZ2NpmeSw5C1gYzt1NvCa text-1.2.4.1
    unix-compat-0.5.3-CsWJk3UHZrh7lbWn5tdOhn

haddock-interfaces:
    /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock

haddock-html:         /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-golden-2.3.4-111-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-golden
version:              2.3.4
visibility:           public
id:                   tasty-golden-2.3.4-4YChGt7yAxYKLhW7AXwrHX
key:                  tasty-golden-2.3.4-4YChGt7yAxYKLhW7AXwrHX
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka
homepage:             https://github.com/feuerbach/tasty-golden
synopsis:             Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.

category:             Testing
abi:                  108fe857fa28fb7505a166d77ef3c57d
exposed:              True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage

hidden-modules:       Test.Tasty.Golden.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/tasty-golden-2.3.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/tasty-golden-2.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/tasty-golden-2.3.4
hs-libraries:         HStasty-golden-2.3.4-4YChGt7yAxYKLhW7AXwrHX
depends:
    async-2.2.3-IdiNIvUG6Je7aMAPJeWE0D base-4.15.0.0
    bytestring-0.10.12.1 containers-0.6.4.1 deepseq-1.4.5.0
    directory-1.3.6.1 filepath-1.4.2.1 mtl-2.2.2
    optparse-applicative-0.16.1.0-2gAu0ltAuRsE34mFhrRUQs
    process-1.6.11.0 tagged-0.8.6.1-FL843C40q4d1DeuwYADr25
    tasty-1.4.2-1aAksKrUWCNHrjKPjUgbfA
    temporary-1.3-1fpZ6Xm8biD79YIGypkFzm text-1.2.4.1
    unix-compat-0.5.3-CsWJk3UHZrh7lbWn5tdOhn

haddock-interfaces:
    /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock

haddock-html:         /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
